@@ -191,12 +191,6 @@ fn create_info_plist(
   bundle_icon_file: Option<PathBuf>,
   settings: &Settings,
 ) -> crate::Result<()> {
-  let format = time::format_description::parse("[year][month][day].[hour][minute][second]")
-    .map_err(time::error::Error::from)?;
-  let build_number = time::OffsetDateTime::now_utc()
-    .format(&format)
-    .map_err(time::error::Error::from)?;
-
   let mut plist = plist::Dictionary::new();
   plist.insert("CFBundleDevelopmentRegion".into(), "English".into());
   plist.insert("CFBundleDisplayName".into(), settings.product_name().into());
@@ -226,7 +220,15 @@ fn create_info_plist(
     "CFBundleShortVersionString".into(),
     settings.version_string().into(),
   );
-  plist.insert("CFBundleVersion".into(), build_number.into());
+  plist.insert(
+    "CFBundleVersion".into(),
+    settings
+      .macos()
+      .bundle_version
+      .as_deref()
+      .unwrap_or_else(|| settings.version_string())
+      .into(),
+  );
   plist.insert("CSResourcesFileMapped".into(), true.into());
   if let Some(category) = settings.app_category() {
     plist.insert(
@@ -269,6 +271,7 @@ fn create_info_plist(
               "CFBundleTypeRole".into(),
               association.role.to_string().into(),
             );
+            dict.insert("LSHandlerRank".into(), association.rank.to_string().into());
             plist::Value::Dictionary(dict)
           })
           .collect(),
