@@ -178,7 +178,11 @@ fn generate_info_plist(
   writeln!(
     file,
     "  <key>CFBundleVersion</key>\n  <string>{}</string>",
-    settings.version_string()
+    settings
+      .ios()
+      .bundle_version
+      .as_deref()
+      .unwrap_or_else(|| settings.version_string())
   )?;
   writeln!(
     file,
