@@ -119,3 +119,23 @@ pub fn run_hook(
 
   Ok(())
 }
+
+#[cfg(target_os = "macos")]
+pub fn strip_semver_prerelease_tag(version: &mut semver::Version) -> crate::Result<()> {
+  if !version.pre.is_empty() {
+    if let Some((_prerelease_tag, number)) = version.pre.as_str().to_string().split_once('.') {
+      version.pre = semver::Prerelease::EMPTY;
+      version.build = semver::BuildMetadata::new(&format!(
+        "{prefix}{number}",
+        prefix = if version.build.is_empty() {
+          "".to_string()
+        } else {
+          format!(".{}", version.build.as_str())
+        }
+      ))
+      .with_context(|| format!("bundle version {number:?} prerelease is invalid"))?;
+    }
+  }
+
+  Ok(())
+}
