@@ -3,7 +3,7 @@
 // SPDX-License-Identifier: MIT
 
 use super::SectionItem;
-use super::{env_nodejs::manager_version, VersionMetadata};
+use super::VersionMetadata;
 use colored::Colorize;
 use serde::Deserialize;
 use std::path::PathBuf;
@@ -76,8 +76,8 @@ pub fn npm_latest_version(pm: &PackageManager, name: &str) -> crate::Result<Opti
   }
 }
 
-pub fn package_manager(app_dir: &PathBuf) -> PackageManager {
-  let found = PackageManager::from_project(app_dir);
+pub fn package_manager(frontend_dir: &PathBuf) -> PackageManager {
+  let found = PackageManager::all_from_project(frontend_dir);
 
   if found.is_empty() {
     println!(
@@ -98,30 +98,22 @@ pub fn package_manager(app_dir: &PathBuf) -> PackageManager {
         );
   }
 
-  if pkg_manager == PackageManager::Yarn
-    && manager_version("yarn")
-      .map(|v| v.chars().next().map(|c| c > '1').unwrap_or_default())
-      .unwrap_or(false)
-  {
-    PackageManager::YarnBerry
-  } else {
-    pkg_manager
-  }
+  pkg_manager
 }
 
 pub fn items(
-  app_dir: Option<&PathBuf>,
+  frontend_dir: Option<&PathBuf>,
   package_manager: PackageManager,
   metadata: &VersionMetadata,
 ) -> Vec<SectionItem> {
   let mut items = Vec::new();
-  if let Some(app_dir) = app_dir {
+  if let Some(frontend_dir) = frontend_dir {
     for (package, version) in [
       ("@tauri-apps/api", None),
       ("@tauri-apps/cli", Some(metadata.js_cli.version.clone())),
     ] {
-      let app_dir = app_dir.clone();
-      let item = nodejs_section_item(package.into(), version, app_dir, package_manager);
+      let frontend_dir = frontend_dir.clone();
+      let item = nodejs_section_item(package.into(), version, frontend_dir, package_manager);
       items.push(item);
     }
   }
@@ -132,13 +124,13 @@ pub fn items(
 pub fn nodejs_section_item(
   package: String,
   version: Option<String>,
-  app_dir: PathBuf,
+  frontend_dir: PathBuf,
   package_manager: PackageManager,
 ) -> SectionItem {
   SectionItem::new().action(move || {
     let version = version.clone().unwrap_or_else(|| {
       package_manager
-        .current_package_version(&package, &app_dir)
+        .current_package_version(&package, &frontend_dir)
         .unwrap_or_default()
         .unwrap_or_default()
     });
