@@ -142,7 +142,7 @@ pub fn exec(
     // Generate Xcode project
     Target::Ios => {
       let (config, metadata) =
-        super::ios::get_config(&app, tauri_config_, None, &Default::default());
+        super::ios::get_config(&app, tauri_config_, None, &Default::default())?;
       map.insert("apple", &config);
       super::ios::project::gen(
         tauri_config_,
