@@ -30,7 +30,7 @@ use crate::{
   helpers::{
     app_paths::tauri_dir,
     config::{BundleResources, Config as TauriConfig, ConfigHandle},
-    pbxproj,
+    pbxproj, strip_semver_prerelease_tag,
   },
   Result,
 };
@@ -39,6 +39,7 @@ use std::{
   env::{set_var, var_os},
   fs::create_dir_all,
   path::PathBuf,
+  str::FromStr,
   thread::sleep,
   time::Duration,
 };
@@ -112,7 +113,7 @@ pub fn get_config(
   tauri_config: &TauriConfig,
   features: Option<&Vec<String>>,
   cli_options: &CliOptions,
-) -> (AppleConfig, AppleMetadata) {
+) -> Result<(AppleConfig, AppleMetadata)> {
   let mut ios_options = cli_options.clone();
   if let Some(features) = features {
     ios_options
@@ -121,6 +122,83 @@ pub fn get_config(
       .extend_from_slice(features);
   }
 
+  let bundle_version = if let Some(bundle_version) = tauri_config
+    .bundle
+    .ios
+    .bundle_version
+    .clone()
+    .or_else(|| tauri_config.version.clone())
+  {
+    // if it's a semver string, we must strip the prerelease tag
+    if let Ok(mut version) = semver::Version::from_str(&bundle_version) {
+      if !version.pre.is_empty() {
+        log::warn!("CFBundleVersion cannot have prerelease tag; stripping from {bundle_version}");
+        strip_semver_prerelease_tag(&mut version)?;
+      }
+      // correctly serialize version - cannot contain `+` as build metadata separator
+      Some(format!(
+        "{}.{}.{}{}",
+        version.major,
+        version.minor,
+        version.patch,
+        if version.build.is_empty() {
+          "".to_string()
+        } else {
+          format!(".{}", version.build.as_str())
+        }
+      ))
+    } else {
+      // let it go as is - cargo-mobile2 will validate it
+      Some(bundle_version)
+    }
+  } else {
+    None
+  };
+  let full_bundle_version_short = if let Some(app_version) = &tauri_config.version {
+    if let Ok(mut version) = semver::Version::from_str(app_version) {
+      if !version.pre.is_empty() {
+        log::warn!(
+          "CFBundleShortVersionString cannot have prerelease tag; stripping from {app_version}"
+        );
+        strip_semver_prerelease_tag(&mut version)?;
+      }
+      // correctly serialize version - cannot contain `+` as build metadata separator
+      Some(format!(
+        "{}.{}.{}{}",
+        version.major,
+        version.minor,
+        version.patch,
+        if version.build.is_empty() {
+          "".to_string()
+        } else {
+          format!(".{}", version.build.as_str())
+        }
+      ))
+    } else {
+      // let it go as is - cargo-mobile2 will validate it
+      Some(app_version.clone())
+    }
+  } else {
+    bundle_version.clone()
+  };
+  let bundle_version_short = if let Some(full_version) = full_bundle_version_short.as_deref() {
+    let mut s = full_version.split('.');
+    let short_version = format!(
+      "{}.{}.{}",
+      s.next().unwrap_or("0"),
+      s.next().unwrap_or("0"),
+      s.next().unwrap_or("0")
+    );
+
+    if short_version != full_version {
+      log::warn!("{full_version:?} is not a valid CFBundleShortVersionString since it must contain exactly three dot separated integers; setting it to {short_version} instead");
+    }
+
+    Some(short_version)
+  } else {
+    None
+  };
+
   let raw = RawAppleConfig {
     development_team: std::env::var(APPLE_DEVELOPMENT_TEAM_ENV_VAR_NAME)
         .ok()
@@ -140,12 +218,12 @@ pub fn get_config(
           }
         }),
     ios_features: ios_options.features.clone(),
-    bundle_version: tauri_config.version.clone(),
-    bundle_version_short: tauri_config.version.clone(),
+    bundle_version,
+    bundle_version_short,
     ios_version: Some(tauri_config.bundle.ios.minimum_system_version.clone()),
     ..Default::default()
   };
-  let config = AppleConfig::from_raw(app.clone(), Some(raw)).unwrap();
+  let config = AppleConfig::from_raw(app.clone(), Some(raw))?;
 
   let tauri_dir = tauri_dir();
 
@@ -194,7 +272,7 @@ pub fn get_config(
   set_var("TAURI_IOS_PROJECT_PATH", config.project_dir());
   set_var("TAURI_IOS_APP_NAME", config.app().name());
 
-  (config, metadata)
+  Ok((config, metadata))
 }
 
 fn connected_device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Device<'a>> {
