@@ -313,8 +313,15 @@ pub fn context_codegen(data: ContextData) -> EmbeddedAssetsResult<TokenStream> {
         plist.insert("CFBundleName".into(), product_name.clone().into());
       }
       if let Some(version) = &config.version {
+        let bundle_version = &config.bundle.macos.bundle_version;
         plist.insert("CFBundleShortVersionString".into(), version.clone().into());
-        plist.insert("CFBundleVersion".into(), version.clone().into());
+        plist.insert(
+          "CFBundleVersion".into(),
+          bundle_version
+            .clone()
+            .unwrap_or_else(|| version.clone())
+            .into(),
+        );
       }
     }
 
