@@ -78,7 +78,7 @@ pub fn get_config(path: &Path) -> Result<(Config, PathBuf), CodegenConfigError>
   // already unlikely unless the developer goes out of their way to run the cli on a different
   // project than the target crate.
   let mut config =
-    serde_json::from_value(tauri_utils::config::parse::read_from(target, parent.clone())?.0)?;
+    serde_json::from_value(tauri_utils::config::parse::read_from(target, &parent)?.0)?;
 
   if let Ok(env) = std::env::var("TAURI_CONFIG") {
     let merge_config: serde_json::Value =
