@@ -28,6 +28,16 @@ fn main() {
 fn main() {
   let args = pico_args::Arguments::from_env().into();
 
+  #[cfg(windows)]
+  let _job_handle = {
+    let job = win32job::Job::create().unwrap();
+    let mut info = job.query_extended_limit_info().unwrap();
+    info.limit_kill_on_job_close();
+    job.set_extended_limit_info(&mut info).unwrap();
+    job.assign_current_process().unwrap();
+    job
+  };
+
   // start the native webdriver on the port specified in args
   let mut driver = webdriver::native(&args);
   let driver = driver
