@@ -349,6 +349,7 @@ pub struct AppHandle<R: Runtime> {
   event_loop: Arc<Mutex<EventLoop>>,
 }
 
+/// Not the real event loop, only contains the main thread id of the event loop
 #[derive(Debug)]
 struct EventLoop {
   main_thread_id: ThreadId,
@@ -389,8 +390,6 @@ impl<R: Runtime> AppHandle<R> {
   ///
   /// Needs to be called from Main Thread
   pub async fn fetch_data_store_identifiers(&self) -> crate::Result<Vec<[u8; 16]>> {
-    use std::sync::Mutex;
-
     let (tx, rx) = tokio::sync::oneshot::channel::<Result<Vec<[u8; 16]>, tauri_runtime::Error>>();
     let lock: Arc<Mutex<Option<_>>> = Arc::new(Mutex::new(Some(tx)));
     let runtime_handle = self.runtime_handle.clone();
@@ -414,8 +413,6 @@ impl<R: Runtime> AppHandle<R> {
   ///
   /// Needs to be called from Main Thread
   pub async fn remove_data_store(&self, uuid: [u8; 16]) -> crate::Result<()> {
-    use std::sync::Mutex;
-
     let (tx, rx) = tokio::sync::oneshot::channel::<Result<(), tauri_runtime::Error>>();
     let lock: Arc<Mutex<Option<_>>> = Arc::new(Mutex::new(Some(tx)));
     let runtime_handle = self.runtime_handle.clone();
@@ -600,6 +597,26 @@ impl<R: Runtime> AppHandle<R> {
       .set_activation_policy(activation_policy)
       .map_err(Into::into)
   }
+
+  /// Sets the dock visibility for the application.
+  ///
+  /// # Examples
+  /// ```,no_run
+  /// tauri::Builder::default()
+  ///   .setup(move |app| {
+  ///     #[cfg(target_os = "macos")]
+  ///     app.handle().set_dock_visibility(false);
+  ///     Ok(())
+  ///   });
+  /// ```
+  #[cfg(target_os = "macos")]
+  #[cfg_attr(docsrs, doc(cfg(target_os = "macos")))]
+  pub fn set_dock_visibility(&self, visible: bool) -> crate::Result<()> {
+    self
+      .runtime_handle
+      .set_dock_visibility(visible)
+      .map_err(Into::into)
+  }
 }
 
 impl<R: Runtime> Manager<R> for AppHandle<R> {
@@ -1129,6 +1146,27 @@ impl<R: Runtime> App<R> {
     }
   }
 
+  /// Sets the dock visibility for the application.
+  ///
+  /// # Examples
+  /// ```,no_run
+  /// tauri::Builder::default()
+  ///   .setup(move |app| {
+  ///     #[cfg(target_os = "macos")]
+  ///     app.set_dock_visibility(false);
+  ///     Ok(())
+  ///   });
+  /// ```
+  #[cfg(target_os = "macos")]
+  #[cfg_attr(docsrs, doc(cfg(target_os = "macos")))]
+  pub fn set_dock_visibility(&mut self, visible: bool) {
+    if let Some(runtime) = self.runtime.as_mut() {
+      runtime.set_dock_visibility(visible);
+    } else {
+      let _ = self.app_handle().set_dock_visibility(visible);
+    }
+  }
+
   /// Change the device event filter mode.
   ///
   /// Since the DeviceEvent capture can lead to high CPU usage for unfocused windows, [`tao`]
@@ -1180,37 +1218,21 @@ impl<R: Runtime> App<R> {
   ///   _ => {}
   /// });
   /// ```
-  pub fn run<F: FnMut(&AppHandle<R>, RunEvent) + 'static>(mut self, mut callback: F) {
-    let app_handle = self.handle().clone();
-    let manager = self.manager.clone();
+  pub fn run<F: FnMut(&AppHandle<R>, RunEvent) + 'static>(mut self, callback: F) {
+    self.handle.event_loop.lock().unwrap().main_thread_id = std::thread::current().id();
 
-    app_handle.event_loop.lock().unwrap().main_thread_id = std::thread::current().id();
-
-    self.runtime.take().unwrap().run(move |event| match event {
-      RuntimeRunEvent::Ready => {
-        if let Err(e) = setup(&mut self) {
-          panic!("Failed to setup app: {e}");
-        }
-        let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Ready, &manager);
-        callback(&app_handle, event);
-      }
-      RuntimeRunEvent::Exit => {
-        let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Exit, &manager);
-        callback(&app_handle, event);
-        app_handle.cleanup_before_exit();
-        if self.manager.restart_on_exit.load(atomic::Ordering::Relaxed) {
-          crate::process::restart(&self.env());
-        }
-      }
-      _ => {
-        let event = on_event_loop_event(&app_handle, event, &manager);
-        callback(&app_handle, event);
-      }
-    });
+    self
+      .runtime
+      .take()
+      .unwrap()
+      .run(self.make_run_event_loop_callback(callback));
   }
 
   /// Runs the application, returning its intended exit code.
   ///
+  /// Note when using [`AppHandle::restart`] and [`AppHandle::request_restart`],
+  /// this function will handle the restart request, exit and restart the app without returning
+  ///
   /// ## Platform-specific
   ///
   /// - **iOS**: Unsupported. The application will fallback to [`run`](Self::run).
@@ -1235,32 +1257,44 @@ impl<R: Runtime> App<R> {
   ///
   /// std::process::exit(exit_code);
   /// ```
-  pub fn run_return<F: FnMut(&AppHandle<R>, RunEvent) + 'static>(mut self, mut callback: F) -> i32 {
-    let manager = self.manager.clone();
-    let app_handle = self.handle().clone();
+  pub fn run_return<F: FnMut(&AppHandle<R>, RunEvent) + 'static>(mut self, callback: F) -> i32 {
+    self.handle.event_loop.lock().unwrap().main_thread_id = std::thread::current().id();
 
     self
       .runtime
       .take()
       .unwrap()
-      .run_return(move |event| match event {
-        RuntimeRunEvent::Ready => {
-          if let Err(e) = setup(&mut self) {
-            panic!("Failed to setup app: {e}");
-          }
-          let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Ready, &manager);
-          callback(&app_handle, event);
+      .run_return(self.make_run_event_loop_callback(callback))
+  }
+
+  fn make_run_event_loop_callback<F: FnMut(&AppHandle<R>, RunEvent) + 'static>(
+    mut self,
+    mut callback: F,
+  ) -> impl FnMut(RuntimeRunEvent<EventLoopMessage>) {
+    let app_handle = self.handle().clone();
+    let manager = self.manager.clone();
+
+    move |event| match event {
+      RuntimeRunEvent::Ready => {
+        if let Err(e) = setup(&mut self) {
+          panic!("Failed to setup app: {e}");
         }
-        RuntimeRunEvent::Exit => {
-          let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Exit, &manager);
-          callback(&app_handle, event);
-          app_handle.cleanup_before_exit();
+        let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Ready, &manager);
+        callback(&app_handle, event);
+      }
+      RuntimeRunEvent::Exit => {
+        let event = on_event_loop_event(&app_handle, RuntimeRunEvent::Exit, &manager);
+        callback(&app_handle, event);
+        app_handle.cleanup_before_exit();
+        if self.manager.restart_on_exit.load(atomic::Ordering::Relaxed) {
+          crate::process::restart(&self.env());
         }
-        _ => {
-          let event = on_event_loop_event(&app_handle, event, &manager);
-          callback(&app_handle, event);
-        }
-      })
+      }
+      _ => {
+        let event = on_event_loop_event(&app_handle, event, &manager);
+        callback(&app_handle, event);
+      }
+    }
   }
 
   /// Runs an iteration of the runtime event loop and immediately return.
@@ -1497,9 +1531,10 @@ impl<R: Runtime> Builder<R> {
   ///
   /// Note that the implementation details is up to your implementation.
   #[must_use]
-  pub fn invoke_system(mut self, initialization_script: String) -> Self {
-    self.invoke_initialization_script =
-      initialization_script.replace("__INVOKE_KEY__", &format!("\"{}\"", self.invoke_key));
+  pub fn invoke_system(mut self, initialization_script: impl AsRef<str>) -> Self {
+    self.invoke_initialization_script = initialization_script
+      .as_ref()
+      .replace("__INVOKE_KEY__", &format!("\"{}\"", self.invoke_key));
     self
   }
 
