@@ -475,10 +475,10 @@ impl RuntimeAuthority {
           )
         }
       } else {
-        let permission_error_detail = if let Some(manifest) = self
+        let permission_error_detail = if let Some((key, manifest)) = self
           .acl
-          .get(key)
-          .or_else(|| self.acl.get(&format!("core:{key}")))
+          .get_key_value(key)
+          .or_else(|| self.acl.get_key_value(&format!("core:{key}")))
         {
           let mut permissions_referencing_command = Vec::new();
 
@@ -501,12 +501,12 @@ impl RuntimeAuthority {
           permissions_referencing_command.sort();
 
           let associated_permissions = permissions_referencing_command
-            .iter()
-            .map(|p| {
+            .into_iter()
+            .map(|permission| {
               if key == APP_ACL_KEY {
-                p.to_string()
+                permission
               } else {
-                format!("{key}:{p}")
+                format!("{key}:{permission}")
               }
             })
             .collect::<Vec<_>>()
@@ -523,8 +523,7 @@ impl RuntimeAuthority {
 
         if let Some(resolved_cmds) = command_matches {
           format!(
-            "{command_pretty_name} not allowed on origin [{}]. Please create a capability that has this origin on the context field.\n\nFound matches for: {}\n\n{permission_error_detail}",
-            origin,
+            "{command_pretty_name} not allowed on origin [{origin}]. Please create a capability that has this origin on the context field.\n\nFound matches for: {}\n\n{permission_error_detail}",
             resolved_cmds
               .iter()
               .map(|resolved| {
@@ -1134,7 +1133,7 @@ mod tests {
     let denied_commands = [(
       command.to_string(),
       vec![ResolvedCommand {
-        windows: windows.clone(),
+        windows,
         ..Default::default()
       }],
     )]
@@ -1186,7 +1185,7 @@ mod tests {
     let resolved_webview_window_remote_cmd = ResolvedCommand {
       windows: vec![Pattern::new(window).unwrap()],
       webviews: vec![Pattern::new(webview).unwrap()],
-      referenced_by: referenced_by.clone(),
+      referenced_by,
       context: ExecutionContext::Remote {
         url: remote_url.parse().unwrap(),
       },
