@@ -219,7 +219,6 @@ pub use {
   self::manager::Asset,
   self::runtime::{
     dpi::{LogicalPosition, LogicalSize, PhysicalPosition, PhysicalSize, Pixel, Position, Size},
-    webview::WebviewAttributes,
     window::{CursorIcon, DragDropEvent, WindowSizeConstraints},
     DeviceEventFilter, Rect, UserAttentionType,
   },
@@ -586,10 +585,7 @@ pub trait Manager<R: Runtime>: sealed::ManagerBase<R> {
     self.manager().get_webview(label).and_then(|webview| {
       let window = webview.window();
       if window.is_webview_window() {
-        Some(WebviewWindow {
-          window: window.clone(),
-          webview,
-        })
+        Some(WebviewWindow { window, webview })
       } else {
         None
       }
@@ -605,13 +601,7 @@ pub trait Manager<R: Runtime>: sealed::ManagerBase<R> {
       .filter_map(|(label, webview)| {
         let window = webview.window();
         if window.is_webview_window() {
-          Some((
-            label,
-            WebviewWindow {
-              window: window.clone(),
-              webview,
-            },
-          ))
+          Some((label, WebviewWindow { window, webview }))
         } else {
           None
         }
@@ -748,11 +738,12 @@ pub trait Manager<R: Runtime>: sealed::ManagerBase<R> {
   where
     T: Send + Sync + 'static,
   {
-    self
-      .manager()
-      .state
-      .try_get()
-      .expect("state() called before manage() for given type")
+    self.manager().state.try_get().unwrap_or_else(|| {
+      panic!(
+        "state() called before manage() for {}",
+        std::any::type_name::<T>()
+      )
+    })
   }
 
   /// Attempts to retrieve the managed state for the type `T`.
