@@ -13,7 +13,7 @@ use std::{
 use serde::Serialize;
 use serialize_to_javascript::{default_template, DefaultTemplate, Template};
 use tauri_runtime::{
-  webview::{DetachedWebview, PendingWebview},
+  webview::{DetachedWebview, InitializationScript, PendingWebview},
   window::DragDropEvent,
 };
 use tauri_utils::config::WebviewUrl;
@@ -178,16 +178,12 @@ impl<R: Runtime> WebviewManager<R> {
       current_window_label = serde_json::to_string(window_label)?,
       current_webview_label = serde_json::to_string(&label)?,
     ));
-    all_initialization_scripts.push(
-      self
-        .initialization_script(
-          app_manager,
-          &ipc_init.into_string(),
-          &pattern_init.into_string(),
-          use_https_scheme,
-        )?
-        .to_string(),
-    );
+    all_initialization_scripts.push(self.initialization_script(
+      app_manager,
+      &ipc_init.into_string(),
+      &pattern_init.into_string(),
+      use_https_scheme,
+    )?);
 
     for plugin_init_script in plugin_init_scripts {
       all_initialization_scripts.push(plugin_init_script.to_string());
@@ -211,9 +207,15 @@ impl<R: Runtime> WebviewManager<R> {
       }
     }
 
-    webview_attributes
-      .initialization_scripts
-      .splice(0..0, all_initialization_scripts);
+    webview_attributes.initialization_scripts.splice(
+      0..0,
+      all_initialization_scripts
+        .into_iter()
+        .map(|script| InitializationScript {
+          script,
+          for_main_frame_only: true,
+        }),
+    );
 
     pending.webview_attributes = webview_attributes;
 
@@ -527,13 +529,17 @@ impl<R: Runtime> WebviewManager<R> {
         os_name: &'a str,
       }
 
-      pending.webview_attributes.initialization_scripts.push(
-        HotkeyZoom {
-          os_name: std::env::consts::OS,
-        }
-        .render_default(&Default::default())?
-        .into_string(),
-      )
+      pending
+        .webview_attributes
+        .initialization_scripts
+        .push(InitializationScript {
+          script: HotkeyZoom {
+            os_name: std::env::consts::OS,
+          }
+          .render_default(&Default::default())?
+          .into_string(),
+          for_main_frame_only: true,
+        })
     }
 
     #[cfg(feature = "isolation")]
