@@ -52,6 +52,10 @@ mod desktop_commands {
     background_throttling: Option<BackgroundThrottlingPolicy>,
     #[serde(default)]
     javascript_disabled: bool,
+    #[serde(default = "default_true")]
+    allow_link_preview: bool,
+    #[serde(default)]
+    pub disable_input_accessory_view: bool,
   }
 
   #[cfg(feature = "unstable")]
@@ -69,6 +73,16 @@ mod desktop_commands {
       builder.webview_attributes.zoom_hotkeys_enabled = config.zoom_hotkeys_enabled;
       builder.webview_attributes.background_throttling = config.background_throttling;
       builder.webview_attributes.javascript_disabled = config.javascript_disabled;
+      builder.webview_attributes.allow_link_preview = config.allow_link_preview;
+      #[cfg(target_os = "ios")]
+      if config.disable_input_accessory_view {
+        builder
+          .webview_attributes
+          .input_accessory_view_builder
+          .replace(tauri_runtime::InputAccessoryViewBuilder::new(Box::new(
+            |_webview| None,
+          )));
+      }
       builder
     }
   }
