@@ -16,7 +16,7 @@ fn get_stream_response(
   request: http::Request<Vec<u8>>,
 ) -> Result<http::Response<Vec<u8>>, Box<dyn std::error::Error>> {
   // skip leading `/`
-  let path = percent_encoding::percent_decode(request.uri().path()[1..].as_bytes())
+  let path = percent_encoding::percent_decode(&request.uri().path().as_bytes()[1..])
     .decode_utf8_lossy()
     .to_string();
 
